@@ -11,6 +11,13 @@ class ActionManager(models.Manager):
         if queryset.exists():
             return queryset.first()
         return None
+    
+    def addIfNotExist(self, action_name):
+        queryset = self.filter(name=action_name)
+        if queryset.exists():
+            return None
+        self.create(name=action_name)
+        return None
 
 class Action(models.Model):
     name = models.CharField(max_length=120)
